Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(460)

Unified Diff: pkg/compiler/lib/src/serialization/constant_serialization.dart

Issue 2603263002: Prefix resolution_types with Resolution. (Closed)
Patch Set: Rebased Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/compiler/lib/src/serialization/constant_serialization.dart
diff --git a/pkg/compiler/lib/src/serialization/constant_serialization.dart b/pkg/compiler/lib/src/serialization/constant_serialization.dart
index 824504adb614220a9333705ffc6d0ff9a71b9425..a3025c2e348be1475c874a88bc6290d634efdb87 100644
--- a/pkg/compiler/lib/src/serialization/constant_serialization.dart
+++ b/pkg/compiler/lib/src/serialization/constant_serialization.dart
@@ -17,9 +17,9 @@ import 'serialization.dart';
/// [ObjectEncoder].
///
/// This class is called from the [Serializer] when a [ConstantExpression] needs
/// serialization. The [ObjectEncoder] ensures that any [Element], [DartType],
/// and other [ConstantExpression] that the serialized [ConstantExpression]
/// depends upon are also serialized.
class ConstantSerializer
extends ConstantExpressionVisitor<dynamic, ObjectEncoder> {
const ConstantSerializer();
@@ -182,7 +182,7 @@ class ConstantDeserializer {
///
/// The class is called from the [Deserializer] when a [ConstantExpression]
/// needs deserialization. The [ObjectDecoder] ensures that any [Element],
/// [DartType], and other [ConstantExpression] that the deserialized
/// [ConstantExpression] depends upon are available.
static ConstantExpression deserialize(ObjectDecoder decoder) {
ConstantExpressionKind kind =
@@ -281,8 +281,8 @@ class ConstantDeserializer {
///
/// This class is called from the [ConstructorSerializer] when the [Serializer]
/// is serializing constant constructor. The [ObjectEncoder] ensures that any
/// [Element], [DartType], and [ConstantExpression] that the serialized
/// [ConstantConstructor] depends upon are also serialized.
class ConstantConstructorSerializer
extends ConstantConstructorVisitor<dynamic, ObjectEncoder> {
const ConstantConstructorSerializer();
@@ -341,13 +341,13 @@ class ConstantConstructorDeserializer {
///
/// The class is called from the [Deserializer] when a constant constructor
/// needs deserialization. The [ObjectDecoder] ensures that any [Element],
/// [DartType], and [ConstantExpression] that the deserialized
/// [ConstantConstructor] depends upon are available.
static ConstantConstructor deserialize(ObjectDecoder decoder) {
ConstantConstructorKind kind =
decoder.getEnum(Key.KIND, ConstantConstructorKind.values);
- DartType readType() {
+ ResolutionDartType readType() {
return decoder.getType(Key.TYPE);
}
« no previous file with comments | « pkg/compiler/lib/src/resolution/typedefs.dart ('k') | pkg/compiler/lib/src/serialization/element_serialization.dart » ('j') | no next file with comments »
@@ -17,9 +17,9 @@ import 'serialization.dart';
///
/// This class is called from the [Serializer] when a [ConstantExpression] needs
-/// serialization. The [ObjectEncoder] ensures that any [Element], [DartType],
-/// and other [ConstantExpression] that the serialized [ConstantExpression]
-/// depends upon are also serialized.
+/// serialization. The [ObjectEncoder] ensures that any [Element],
+/// [ResolutionDartType], and other [ConstantExpression] that the serialized
+/// [ConstantExpression] depends upon are also serialized.
class ConstantSerializer
extends ConstantExpressionVisitor<dynamic, ObjectEncoder> {
@@ -182,7 +182,7 @@ class ConstantDeserializer {
/// The class is called from the [Deserializer] when a [ConstantExpression]
/// needs deserialization. The [ObjectDecoder] ensures that any [Element],
- /// [DartType], and other [ConstantExpression] that the deserialized
+ /// [ResolutionDartType], and other [ConstantExpression] that the deserialized
/// [ConstantExpression] depends upon are available.
static ConstantExpression deserialize(ObjectDecoder decoder) {
@@ -281,8 +281,8 @@ class ConstantDeserializer {
/// This class is called from the [ConstructorSerializer] when the [Serializer]
/// is serializing constant constructor. The [ObjectEncoder] ensures that any
-/// [Element], [DartType], and [ConstantExpression] that the serialized
-/// [ConstantConstructor] depends upon are also serialized.
+/// [Element], [ResolutionDartType], and [ConstantExpression] that the
+/// serialized [ConstantConstructor] depends upon are also serialized.
class ConstantConstructorSerializer
extends ConstantConstructorVisitor<dynamic, ObjectEncoder> {
@@ -341,13 +341,13 @@ class ConstantConstructorDeserializer {
/// The class is called from the [Deserializer] when a constant constructor
/// needs deserialization. The [ObjectDecoder] ensures that any [Element],
- /// [DartType], and [ConstantExpression] that the deserialized
+ /// [ResolutionDartType], and [ConstantExpression] that the deserialized
/// [ConstantConstructor] depends upon are available.
static ConstantConstructor deserialize(ObjectDecoder decoder) {

Powered by Google App Engine
This is Rietveld 408576698